LivenessConfig class

Configuration for the Liveness Detection widget

Constructors

LivenessConfig({bool enableSmile = true, bool enableBlink = true, bool enableMotion = true, int requiredDetections = 10, int requiredBlinks = 3, void onSuccess(String? imagePath)?, void onCancel()?, bool showDefaultSuccessScreen = true})
const

Properties

Enable blink detection task
final
enableMotion bool
Enable motion detection task
final
enableSmile bool
Enable smile detection task
final
hasAnyTask bool
Check if at least one task is enabled
no setter
hashCode int
The hash code for this object.
no setterinherited
onCancel → void Function()?
Callback when user cancels the verification
final
onSuccess → void Function(String? imagePath)?
Callback when all tasks are completed successfully
final
Number of blinks required (accumulative)
final
requiredDetections int
Number of consecutive detections required for smile/motion
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDefaultSuccessScreen bool
Custom success screen widget (optional)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited